==> jc-1.4.0.tar.gz: gnu/java/security/provider/PKIXCertPathValidatorImpl.h <==
// public class gnu.java.security.provider.PKIXCertPathValidatorImpl

// class file dependencies
// @dep_class e5b359b7eeaed090 gnu_java_security_provider_PKIXCertPathValidatorImpl
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class f36fbe7f99064be7 java_security_cert_CertPathValidatorSpi

// header file dependencies
// @dep_header java_security_cert_CertPathValidatorSpi

#include "java/security/cert/CertPathValidatorSpi.h"

#ifndef _JC_gnu_java_security_provider_PKIXCertPathValidatorImpl_H_
#define _JC_gnu_java_security_provider_PKIXCertPathValidatorImpl_H_

// Forward structure declarations
struct _jc_gnu_java_security_x509_PolicyNodeImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_cert_CertPath$object;
struct _jc_java_security_cert_CertPathParameters$object;
struct _jc_java_security_cert_CertPathValidatorResult$object;
struct _jc_java_security_cert_PKIXParameters$object;
struct _jc_java_security_cert_X509CRL$object;
struct _jc_java_security_cert_X509Certificate$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_refs	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_refs;
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_nonrefs	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$refs	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$refs;
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$nonrefs	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$nonrefs;
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object;

typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$fields_struct	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$fields_struct;
typedef const struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vmethods	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vmethods;
typedef const struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtable	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtable;
typedef const struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$fields_struct {
	struct _jc_java_lang_String$object	*ANY__5fPOLICY;
	jboolean	DEBUG;
};
extern _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$fields_struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *);

// Virtual methods
extern jboolean _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$checkExplicitPolicy$f637af9b65254956(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *, jint, struct _jc_object *);
extern struct _jc_object *_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$engineValidate$38351e7608bca8b6(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method_info$checkExplicitPolicy$f637af9b65254956;
extern _jc_method _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method_info$engineValidate$38351e7608bca8b6;

// Static methods
extern void _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$basicSanity$ad49fe2782b28131(_jc_env *, struct _jc_object_array *, jint);
extern jboolean _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$checkCRL$e84285ad080c9e9e(_jc_env *, struct _jc_java_security_cert_X509CRL$object *, struct _jc_object_array *, struct _jc_java_util_Date$object *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_object *, struct _jc_object *);
extern void _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$debug$1e3312c3736b0b51(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_object *_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$getCritExts$a6e87aacd1cc9411(_jc_env *, struct _jc_java_security_cert_X509Certificate$object *);
extern void _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$updatePolicyTree$08536ed1c0eeb7b6(_jc_env *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_gnu_java_security_x509_PolicyNodeImpl$object *, jint, struct _jc_java_security_cert_PKIXParameters$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vmethods {
	jboolean	(*checkExplicitPolicy$f637af9b65254956)(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *, jint, struct _jc_object *);
	struct _jc_object	*(*engineValidate$38351e7608bca8b6)(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathValidatorSpi$vmethods	java_security_cert_CertPathValidatorSpi;
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vmethods	gnu_java_security_provider_PKIXCertPathValidatorImpl;
};

// Vtype
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$refs {
    _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_refs	gnu_java_security_provider_PKIXCertPathValidatorImpl;
    _jc_java_security_cert_CertPathValidatorSpi$sub_refs	java_security_cert_CertPathValidatorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs	java_security_cert_CertPathValidatorSpi;
    _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_nonrefs	gnu_java_security_provider_PKIXCertPathValidatorImpl;
};

// Object instance structure
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object {
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype	*vtype;
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_PKIXCertPathValidatorImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$class_object;

#endif	/* _JC_gnu_java_security_provider_PKIXCertPathValidatorImpl_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/PKIXCertPathValidatorImpl.h <==
// public class gnu.java.security.provider.PKIXCertPathValidatorImpl

// class file dependencies
// @dep_class 66a3fe77442b5cf5 gnu_java_security_provider_PKIXCertPathValidatorImpl
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class f36fbe7f99064be7 java_security_cert_CertPathValidatorSpi

// header file dependencies
// @dep_header java_security_cert_CertPathValidatorSpi

#include "java/security/cert/CertPathValidatorSpi.h"

#ifndef _JC_gnu_java_security_provider_PKIXCertPathValidatorImpl_H_
#define _JC_gnu_java_security_provider_PKIXCertPathValidatorImpl_H_

// Forward structure declarations
struct _jc_gnu_java_security_x509_PolicyNodeImpl$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_PublicKey$object;
struct _jc_java_security_cert_CertPath$object;
struct _jc_java_security_cert_CertPathParameters$object;
struct _jc_java_security_cert_CertPathValidatorResult$object;
struct _jc_java_security_cert_PKIXParameters$object;
struct _jc_java_security_cert_X509CRL$object;
struct _jc_java_security_cert_X509Certificate$object;
struct _jc_java_util_Date$object;
struct _jc_java_util_List$object;
struct _jc_java_util_Set$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_refs	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_refs;
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_nonrefs	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$refs	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$refs;
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$nonrefs	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$nonrefs;
typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object;

typedef struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$fields_struct	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$fields_struct;
typedef const struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vmethods	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vmethods;
typedef const struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtable	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtable;
typedef const struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$fields_struct {
	struct _jc_java_lang_String$object	*ANY__5fPOLICY;
	jboolean	DEBUG;
};
extern _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$fields_struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$checkExplicitPolicy$f637af9b65254956(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *, jint, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$engineValidate$38351e7608bca8b6(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method_info$checkExplicitPolicy$f637af9b65254956;
extern _jc_method _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method_info$engineValidate$38351e7608bca8b6;

// Static methods
extern void _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$basicSanity$ad49fe2782b28131(_jc_env *, struct _jc_object_array *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$checkCRL$e84285ad080c9e9e(_jc_env *, struct _jc_java_security_cert_X509CRL$object *, struct _jc_object_array *, struct _jc_java_util_Date$object *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$debug$1e3312c3736b0b51(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$getCritExts$a6e87aacd1cc9411(_jc_env *, struct _jc_java_security_cert_X509Certificate$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$method$updatePolicyTree$08536ed1c0eeb7b6(_jc_env *, struct _jc_java_security_cert_X509Certificate$object *, struct _jc_gnu_java_security_x509_PolicyNodeImpl$object *, jint, struct _jc_java_security_cert_PKIXParameters$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vmethods {
	jboolean	(*checkExplicitPolicy$f637af9b65254956)(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *, jint, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*engineValidate$38351e7608bca8b6)(_jc_env *, struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object *, struct _jc_java_security_cert_CertPath$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_cert_CertPathValidatorSpi$vmethods	java_security_cert_CertPathValidatorSpi;
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vmethods	gnu_java_security_provider_PKIXCertPathValidatorImpl;
};

// Vtype
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$refs {
    _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_refs	gnu_java_security_provider_PKIXCertPathValidatorImpl;
    _jc_java_security_cert_CertPathValidatorSpi$sub_refs	java_security_cert_CertPathValidatorSpi;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_cert_CertPathValidatorSpi$sub_nonrefs	java_security_cert_CertPathValidatorSpi;
    _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$sub_nonrefs	gnu_java_security_provider_PKIXCertPathValidatorImpl;
};

// Object instance structure
struct _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$object {
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype	*vtype;
	_jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$vtype _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_PKIXCertPathValidatorImpl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_PKIXCertPathValidatorImpl$class_object;

#endif	/* _JC_gnu_java_security_provider_PKIXCertPathValidatorImpl_H_ */
